@@ -1,5 +1,5 @@
 package AnyEvent::Handle::UDP;
-$AnyEvent::Handle::UDP::VERSION = '0.045';
+$AnyEvent::Handle::UDP::VERSION = '0.046';
 use strict;
 use warnings;
 
@@ -63,6 +63,11 @@ for my $name (qw/sockname peername/) {
 	});
 }
 
+sub fh {
+	my $self = shift;
+	return $self->{fh};
+}
+
 sub on_drain {
 	my $self = shift;
 	if (@_) {
@@ -310,7 +315,7 @@ AnyEvent::Handle::UDP - client/server UDP handles for AnyEvent
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 SYNOPSIS
 
